*******************************************************************************
*****                     Replication code for                             ****
***** Erhardt et al. - National Identity between Democracy and Autocracy   ****
*****                  Part II: Empirical analysis                         ****
*******************************************************************************
    





*******************************************************************************

*** 1. Preparations

use "EPSR Erhardt et al", clear

xtset country
global controls "c.age##c.age sex education income_cat i.workstat unempexp weldepexp i.maritalstat children religious_attendance i.migration_background c.rile##c.rile interestpolitics gentrust specificsupport"
global controls_full "c.age##c.age sex education income_cat i.workstat unempexp weldepexp i.maritalstat children religious_attendance i.migration_background c.rile##c.rile polsystem_democratic specificsupport interestpolitics immigrants trust_particularized gentrust clubmem nationalpride valuesm authoritarianism"
global controls_socdem "c.age##c.age sex education income_cat i.workstat unempexp weldepexp i.maritalstat children religious_attendance i.migration_background"





*******************************************************************************

*** 2. Descriptive statistics etc.

**Factor analysis

*Factor analysis Democracy-autocracy-preference
factor dap_leader dap_army dap_democracy, pcf
rotate, promax blank(0.5)

*Factor analysis National identity
factor civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions, pcf
rotate, promax blank(0.5)



**Summary statistics

*Table A1: Variables, data source and summary statistics
sum dap_democracy dap_leader dap_army prefsystemm3 civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions ethnicm civicm civicm_3item civicm_alt civicethnicm income_cat unempexp weldepexp age sex education i.workstat i.maritalstat children religious_attendance i.migration_background rile interestpolitics gentrust specificsupport polsystem_democratic immigrants trust_particularized clubmem nationalpride valuesm authoritarianism
bysort country: gen test = _n
sum gdppc_log unemp gini rr_mean growth KOFGI netmigrationrate gee fh if test==1
drop test

*Table A2: Frequency tables for the key variables
tab1 dap_democracy dap_leader dap_army civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions

*Differences between Western and Eastern European countries, see footnote 18
tab1 dap_democracy dap_leader dap_army civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions if west==1
tab1 dap_democracy dap_leader dap_army civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions if west==0

foreach var of varlist dap_democracy dap_leader dap_army civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions {
recode `var' (1 2 = 0) (3 4 = 1), gen(d_`var')
}
tab country, sum(d_dap_democracy)
tab country, sum(d_dap_leader)
tab country, sum(d_dap_army)
tab country, sum(d_civicethnic_ancestry)
tab country, sum(d_civicethnic_born)
tab country, sum(d_civicethnic_culture)
tab country, sum(d_civicethnic_language)
tab country, sum(d_civicethnic_institutions)
drop d_*








*******************************************************************************

*** 3. Empirical analysis part 1: Direct effects

** Run and store models

*Main models, used in Figure 2 and Table A3
xtreg dap_democracy civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls , vce(rob) fe
eststo democracy

xtreg dap_leader civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls , vce(rob) fe
eststo leader

xtreg dap_army civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls , vce(rob) fe
eststo army

*Robustness check: Western Europe, used in Figure A1
xtreg dap_democracy civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls if west==1, vce(rob) fe
eststo democracy_west

xtreg dap_leader civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls if west==1, vce(rob) fe
eststo leader_west

xtreg dap_army civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls if west==1, vce(rob) fe
eststo army_west

*Robustness check: Eastern Europe, used in Figure A1
xtreg dap_democracy civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls if west==0, vce(rob) fe
eststo democracy_east

xtreg dap_leader civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls if west==0, vce(rob) fe
eststo leader_east

xtreg dap_army civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls if west==0, vce(rob) fe
eststo army_east

*Robustness check: Less controls (only socio-demographic controls), used in Figure A1, see footnote 12
xtreg dap_democracy civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls_socdem , vce(rob) fe
eststo democracy_cvsocdem

xtreg dap_leader civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls_socdem , vce(rob) fe
eststo leader_cvsocdem

xtreg dap_army civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls_socdem , vce(rob) fe
eststo army_cvsocdem

*Robustness check: More controls, used in Figure A1, see footnote 12
xtreg dap_democracy civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls_full , vce(rob) fe
eststo democracy_full

xtreg dap_leader civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls_full , vce(rob) fe
eststo leader_full

xtreg dap_army civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls_full , vce(rob) fe
eststo army_full

*Robustness check: Ordered logit, used in Figure A1, see footnote 8
ologit dap_democracy civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls i.country, vce(cl country)
eststo democracy_ologit

ologit dap_leader civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls i.country, vce(cl country)
eststo leader_ologit

ologit dap_army civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls i.country, vce(cl country)
eststo army_ologit

*Robustness check: Multilevel models, used in Figure A1, see footnote 9
mixed dap_democracy civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls gdppc_log unemp gini KOFGI growth netmigrationrate gee fh, vce(rob)
eststo democracy_mixed

mixed dap_leader civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls gdppc_log unemp gini KOFGI growth netmigrationrate gee fh, vce(rob)
eststo leader_mixed

mixed dap_army civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls gdppc_log unemp gini KOFGI growth netmigrationrate gee fh, vce(rob)
eststo army_mixed

*Robustness check: Ethnic and civic national identity indices, used in Table A2
xtreg dap_democracy ethnicm civicm $controls , vce(rob) fe
eststo democracy_ind

xtreg dap_leader ethnicm civicm $controls , vce(rob) fe
eststo leader_ind

xtreg dap_army ethnicm civicm $controls , vce(rob) fe
eststo army_ind

*Robustness check: Combined ethnic-civic index, used in Table A2, see footnote 13
xtreg dap_democracy civicethnicm $controls , vce(rob) fe
eststo democracy_ind2

xtreg dap_leader civicethnicm $controls , vce(rob) fe
eststo leader_ind2

xtreg dap_army civicethnicm $controls , vce(rob) fe
eststo army_ind2

*Robustness check: Alternative civic national identity index, used in Table A2, see footnote 13
xtreg dap_democracy civicm_alt $controls , vce(rob) fe
eststo democracy_ind3

xtreg dap_leader civicm_alt $controls , vce(rob) fe
eststo leader_ind3

xtreg dap_army civicm_alt $controls , vce(rob) fe
eststo army_ind3

*Robustness check: Jackknifing models
levelsof country, local(levels) 
foreach l of local levels {
tab country if country == `l'
xtreg dap_democracy civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls if country != `l', vce(rob) fe
}

levelsof country, local(levels) 
foreach l of local levels {
tab country if country == `l'
xtreg dap_leader civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls if country != `l', vce(rob) fe
}

levelsof country, local(levels) 
foreach l of local levels {
tab country if country == `l'
xtreg dap_army civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls if country != `l', vce(rob) fe
}




** Figures and Tables

*Figure 2: Regression coefficients of the relation between ethnic or civic national identity and support for democracy as opposed to authoritarian alternatives
coefplot democracy, bylabel(Democratic rule) || leader, bylabel(Leader rule) || army, bylabel(Army rule) ||, keep(civicethnic_*) xline(0, lpattern(dash) lcolor(gray) lwidth(medthick)) ciopts(lcolor(black)) mcolor(black) xlab(, labsize(large)) coeflabels(civicethnic_ancestry = "Ancestry" civicethnic_born = "Born" civicethnic_culture = "Culture" civicethnic_language = "Language" civicethnic_institutions = "Institutions", labsize(large)) graphregion(color(white)) scheme(s1mono) byopts(rows(1)) 
graph export "Figure 2.png", replace

*Table A3: Regression models of the relation between ethnic or civic national identity and support for democracy as opposed to authoritarian alternatives
esttab democracy leader army using "Table A3.rtf", replace b(3) se(2) wide compress sfmt(%10.0f %10.0f %10.3f) scalar(N N_g) ar2 staraux alignment(cr) nobase star(+ 0.10 * 0.05 ** 0.01 *** 0.001)

*Figure A1: Robustness checks for the relation between ethnic or civic national identity and support for democracy as opposed to authoritarian alternatives, Panel Democratic rule
coefplot democracy democracy_west democracy_east democracy_cvsocdem democracy_full democracy_ologit democracy_mixed, keep(civicethnic_*) xline(0, lpattern(dash) lcolor(gray) lwidth(medthick)) legend(order(2 "Main model" 4 "Western Europe" 6 "Eastern Europe" 8 "Less controls" 10 "More controls" 12 "Ordered logit" 14 "Multilevel") rows(3)) ciopts(lcolor(black)) mcolor(black) xlab(, labsize(large)) coeflabels(civicethnic_ancestry = "Ancestry" civicethnic_born = "Born" civicethnic_culture = "Culture" civicethnic_language = "Language" civicethnic_institutions = "Institutions", labsize(large)) graphregion(color(white)) scheme(s1mono) title("", size(vlarge))
graph export "Figure A1, Democratic rule.png", replace

*Figure A1: Robustness checks for the relation between ethnic or civic national identity and support for democracy as opposed to authoritarian alternatives, Panel Leader rule
coefplot leader leader_west leader_east leader_cvsocdem leader_full leader_ologit leader_mixed, keep(civicethnic_*) xline(0, lpattern(dash) lcolor(gray) lwidth(medthick)) legend(order(2 "Main model" 4 "Western Europe" 6 "Eastern Europe" 8 "Less controls" 10 "More controls" 12 "Ordered logit" 14 "Multilevel") rows(3)) ciopts(lcolor(black)) mcolor(black) xlab(, labsize(large)) coeflabels(civicethnic_ancestry = "Ancestry" civicethnic_born = "Born" civicethnic_culture = "Culture" civicethnic_language = "Language" civicethnic_institutions = "Institutions", labsize(large)) graphregion(color(white)) scheme(s1mono) title("", size(vlarge))
graph export "Figure A1, Leader rule.png", replace

*Figure A1: Robustness checks for the relation between ethnic or civic national identity and support for democracy as opposed to authoritarian alternatives, Panel Army rule
coefplot army army_west army_east army_cvsocdem army_full army_ologit army_mixed, keep(civicethnic_*) xline(0, lpattern(dash) lcolor(gray) lwidth(medthick)) legend(order(2 "Main model" 4 "Western Europe" 6 "Eastern Europe" 8 "Less controls" 10 "More controls" 12 "Ordered logit" 14 "Multilevel") rows(3)) ciopts(lcolor(black)) mcolor(black) xlab(, labsize(large)) coeflabels(civicethnic_ancestry = "Ancestry" civicethnic_born = "Born" civicethnic_culture = "Culture" civicethnic_language = "Language" civicethnic_institutions = "Institutions", labsize(large)) graphregion(color(white)) scheme(s1mono) title("", size(vlarge))
graph export "Figure A1, Army rule.png", replace



**Other calculations

*Standardized coefficients to compare size with other control variables
global controls_std "c.age##c.age sex education income_cat workstat2-workstat7 unempexp weldepexp maritalstat2-maritalstat4 children religious_attendance migration_background2 migration_background3 c.rile##c.rile specificsupport interestpolitics gentrust"

xtreg dap_democracy civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls_std , vce(rob) fe
preserve
keep if e(sample)
center dap_democracy civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions age age2 sex education income_cat workstat2-workstat7 unempexp weldepexp maritalstat2-maritalstat4 children religious_attendance migration_background2 migration_background3 rile rile2 specificsupport interestpolitics gentrust, inplace standardize
xtreg dap_democracy civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls_std , vce(rob) fe
margins, dydx(age) at(age=50)
margins, dydx(rile) at(rile=5.4)
restore

xtreg dap_leader civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls_std , vce(rob) fe
preserve
keep if e(sample)
center dap_leader civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions age age2 sex education income_cat workstat2-workstat7 unempexp weldepexp maritalstat2-maritalstat4 children religious_attendance migration_background2 migration_background3 rile rile2 specificsupport interestpolitics gentrust, inplace standardize
xtreg dap_leader civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls_std , vce(rob) fe
margins, dydx(age) at(age=50)
margins, dydx(rile) at(rile=5.4)
restore

xtreg dap_army civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls_std , vce(rob) fe
preserve
keep if e(sample)
center dap_army civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions age age2 sex education income_cat workstat2-workstat7 unempexp weldepexp maritalstat2-maritalstat4 children religious_attendance migration_background2 migration_background3 rile rile2 specificsupport interestpolitics gentrust, inplace standardize
xtreg dap_army civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls_std , vce(rob) fe
margins, dydx(age) at(age=50)
margins, dydx(rile) at(rile=5.4)
restore

*Effect sizes
est resto democracy
mchange civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions, amount(range)
est resto leader
mchange civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions, amount(range)
est resto army
mchange civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions, amount(range)









*******************************************************************************

*** 4. Empirical analysis part 2: Interaction effects

** Run and store models

*Main models, used in Table 2 and Table A5
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.income_cat) $controls , vce(rob) fe
eststo iincome
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.unempexp) $controls , vce(rob) fe
eststo iunempexp
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.weldepexp) $controls , vce(rob) fe
eststo iweldepexp

xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.gdppc_log) $controls , vce(rob) fe
eststo igdppc
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.unemp) $controls , vce(rob) fe
eststo iunemp
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.gini) $controls , vce(rob) fe
eststo igini
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.rr_mean) $controls , vce(rob) fe
eststo irr

*Robustness check: Western Europe, used in Figure A2
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.income_cat) $controls  if west==1, vce(rob) fe
eststo iincome_west
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.unempexp) $controls  if west==1, vce(rob) fe
eststo iunempexp_west
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.weldepexp) $controls  if west==1, vce(rob) fe
eststo iweldepexp_west

xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.gdppc_log) $controls if west==1, vce(rob) fe
eststo igdppc_west
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.unemp) $controls  if west==1, vce(rob) fe
eststo iunemp_west
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.gini) $controls  if west==1, vce(rob) fe
eststo igini_west
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.rr_mean) $controls  if west==1, vce(rob) fe
eststo irr_west

*Robustness check: Eastern Europe, used in Figure A2
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.income_cat) $controls  if west==0, vce(rob) fe
eststo iincome_east
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.unempexp) $controls  if west==0, vce(rob) fe
eststo iunempexp_east
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.weldepexp) $controls  if west==0, vce(rob) fe
eststo iweldepexp_east

xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.gdppc_log) $controls if west==0, vce(rob) fe
eststo igdppc_east
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.unemp) $controls  if west==0, vce(rob) fe
eststo iunemp_east
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.gini) $controls  if west==0, vce(rob) fe
eststo igini_east
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.rr_mean) $controls  if west==0, vce(rob) fe
eststo irr_east

*Robustness check: Less controls (only socio-demographic controls), used in Figure A2, see footnote 12
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.income_cat) $controls_socdem , vce(rob) fe
eststo iincome_cvsocdem
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.unempexp) $controls_socdem , vce(rob) fe
eststo iunempexp_cvsocdem
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.weldepexp) $controls_socdem , vce(rob) fe
eststo iweldepexp_cvsocdem

xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.gdppc_log) $controls_socdem , vce(rob) fe
eststo igdppc_cvsocdem
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.unemp) $controls_socdem , vce(rob) fe
eststo iunemp_cvsocdem
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.gini) $controls_socdem , vce(rob) fe
eststo igini_cvsocdem
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.rr_mean) $controls_socdem , vce(rob) fe
eststo irr_cvsocdem

*Robustness check: More controls, used in Figure A2, see footnote 12
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.income_cat) $controls_full , vce(rob) fe
eststo iincome_full
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.unempexp) $controls_full , vce(rob) fe
eststo iunempexp_full
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.weldepexp) $controls_full , vce(rob) fe
eststo iweldepexp_full

xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.gdppc_log) $controls_full , vce(rob) fe
eststo igdppc_full
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.unemp) $controls_full , vce(rob) fe
eststo iunemp_full
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.gini) $controls_full , vce(rob) fe
eststo igini_full
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.rr_mean) $controls_full , vce(rob) fe
eststo irr_full

*Robustness check: Ordered logit, used in Figure A2, see footnote 8
ologit prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.income_cat) $controls i.country, vce(rob)
eststo iincome_ologit
ologit prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.unempexp) $controls i.country, vce(rob)
eststo iunempexp_ologit
ologit prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.weldepexp) $controls i.country, vce(rob)
eststo iweldepexp_ologit

ologit prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.gdppc_log) $controls i.country, vce(rob)
eststo igdppc_ologit
ologit prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.unemp) $controls i.country, vce(rob)
eststo iunemp_ologit
ologit prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.gini) $controls i.country, vce(rob)
eststo igini_ologit
ologit prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.rr_mean) $controls i.country, vce(rob)
eststo irr_ologit

*Robustness check: Multilevel models, used in Figure A2, see footnote 9
mixed prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.income_cat) $controls c.gdppc_log c.unemp c.gini c.KOFGI c.growth c.netmigrationrate c.gee c.fh, vce(rob)
eststo iincome_mixed
mixed prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.unempexp) $controls c.gdppc_log c.unemp c.gini c.KOFGI c.growth c.netmigrationrate c.gee c.fh, vce(rob)
eststo iunempexp_mixed
mixed prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.weldepexp) $controls c.gdppc_log c.unemp c.gini c.KOFGI c.growth c.netmigrationrate c.gee c.fh, vce(rob)
eststo iweldepexp_mixed

mixed prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.gdppc_log) $controls c.gdppc_log c.unemp c.gini c.KOFGI c.growth c.netmigrationrate c.gee c.fh, vce(rob)
eststo igdppc_mixed
mixed prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.unemp) $controls c.gdppc_log c.unemp c.gini c.KOFGI c.growth c.netmigrationrate c.gee c.fh, vce(rob)
eststo iunemp_mixed
mixed prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.gini) $controls c.gdppc_log c.unemp c.gini c.KOFGI c.growth c.netmigrationrate c.gee c.fh, vce(rob)
eststo igini_mixed
mixed prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.rr_mean) $controls c.gdppc_log c.unemp c.gini c.KOFGI c.growth c.netmigrationrate c.gee c.fh, vce(rob)
eststo irr_mixed

*Robustness check: 3-item civic national identity index, used in Figure A2, see footnote 13
xtreg prefsystemm3 c.ethnicm c.civicm_3item (c.ethnicm c.civicm_3item)#(c.income_cat) $controls , vce(rob) fe
eststo iincome_civic3
xtreg prefsystemm3 c.ethnicm c.civicm_3item (c.ethnicm c.civicm_3item)#(c.unempexp) $controls , vce(rob) fe
eststo iunempexp_civic3
xtreg prefsystemm3 c.ethnicm c.civicm_3item (c.ethnicm c.civicm_3item)#(c.weldepexp) $controls , vce(rob) fe
eststo iweldepexp_civic3

xtreg prefsystemm3 c.ethnicm c.civicm_3item (c.ethnicm c.civicm_3item)#(c.gdppc_log) $controls , vce(rob) fe
eststo igdppc_civic3
xtreg prefsystemm3 c.ethnicm c.civicm_3item (c.ethnicm c.civicm_3item)#(c.unemp) $controls , vce(rob) fe
eststo iunemp_civic3
xtreg prefsystemm3 c.ethnicm c.civicm_3item (c.ethnicm c.civicm_3item)#(c.gini) $controls , vce(rob) fe
eststo igini_civic3
xtreg prefsystemm3 c.ethnicm c.civicm_3item (c.ethnicm c.civicm_3item)#(c.rr_mean) $controls , vce(rob) fe
eststo irr_civic3

*Robustness check: Combined ethnic-civic index, used in Figure A2, see footnote 13
xtreg prefsystemm3 c.civicethnicm (c.civicethnicm)#(c.income_cat) $controls , vce(rob) fe
eststo iincome_ind2
xtreg prefsystemm3 c.civicethnicm (c.civicethnicm)#(c.unempexp) $controls , vce(rob) fe
eststo iunempexp_ind2
xtreg prefsystemm3 c.civicethnicm (c.civicethnicm)#(c.weldepexp) $controls , vce(rob) fe
eststo iweldepexp_ind2

xtreg prefsystemm3 c.civicethnicm (c.civicethnicm)#(c.gdppc_log) $controls , vce(rob) fe
eststo igdppc_ind2
xtreg prefsystemm3 c.civicethnicm (c.civicethnicm)#(c.unemp) $controls , vce(rob) fe
eststo iunemp_ind2
xtreg prefsystemm3 c.civicethnicm (c.civicethnicm)#(c.gini) $controls , vce(rob) fe
eststo igini_ind2
xtreg prefsystemm3 c.civicethnicm (c.civicethnicm)#(c.rr_mean) $controls , vce(rob) fe
eststo irr_ind2

*Robustness check: Alternative civic national identity index, used in Figure A2, see footnote 13
xtreg prefsystemm3 c.civicm_alt (c.civicm_alt)#(c.income_cat) $controls , vce(rob) fe
eststo iincome_ind3
xtreg prefsystemm3 c.civicm_alt (c.civicm_alt)#(c.unempexp) $controls , vce(rob) fe
eststo iunempexp_ind3
xtreg prefsystemm3 c.civicm_alt (c.civicm_alt)#(c.weldepexp) $controls , vce(rob) fe
eststo iweldepexp_ind3

xtreg prefsystemm3 c.civicm_alt (c.civicm_alt)#(c.gdppc_log) $controls , vce(rob) fe
eststo igdppc_ind3
xtreg prefsystemm3 c.civicm_alt (c.civicm_alt)#(c.unemp) $controls , vce(rob) fe
eststo iunemp_ind3
xtreg prefsystemm3 c.civicm_alt (c.civicm_alt)#(c.gini) $controls , vce(rob) fe
eststo igini_ind3
xtreg prefsystemm3 c.civicm_alt (c.civicm_alt)#(c.rr_mean) $controls , vce(rob) fe
eststo irr_ind3

*Robustness check: Jackknifing models
levelsof country, local(levels) 
foreach l of local levels {
tab country if country == `l'
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.gdppc_log) $controls if country != `l', vce(rob) fe
eststo igdppc_jk`l'
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.unemp) $controls if country != `l', vce(rob) fe
eststo iunemp_jk`l'
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.gini) $controls if country != `l', vce(rob) fe
eststo igini_jk`l'

xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.income_cat) $controls if country != `l', vce(rob) fe
eststo iincome_jk`l'
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.unempexp) $controls if country != `l', vce(rob) fe
eststo iunempexp_jk`l'
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.weldepexp) $controls if country != `l', vce(rob) fe
eststo iweldepexp_jk`l'
}






** Figures and Tables

*Table 2: Regression coefficients of the moderating effect of economic hardship on the relation between ethnic or civic national identity and support for democracy as opposed to authoritarian alternatives
est res iincome
eststo iincome_ethnic_insec: margins, dydx(c.ethnicm) at(income_cat=(1)) post //Min: 1
est res iincome
eststo iincome_ethnic_sec: margins, dydx(c.ethnicm) at(income_cat=(10)) post //Max: 10
est res iincome
eststo iincome_civic_insec: margins, dydx(c.civicm) at(income_cat=(1)) post //Min: 1
est res iincome
eststo iincome_civic_sec: margins, dydx(c.civicm) at(income_cat=(10)) post //Max: 10

est res iunempexp
eststo iunempexp_ethnic_insec: margins, dydx(c.ethnicm) at(unempexp=(1)) post //Max: 1
est res iunempexp
eststo iunempexp_ethnic_sec: margins, dydx(c.ethnicm) at(unempexp=(0)) post //Min: 0
est res iunempexp
eststo iunempexp_civic_insec: margins, dydx(c.civicm) at(unempexp=(1)) post //Max: 1
est res iunempexp
eststo iunempexp_civic_sec: margins, dydx(c.civicm) at(unempexp=(0)) post //Min: 0

est res iweldepexp
eststo iweldepexp_ethnic_insec: margins, dydx(c.ethnicm) at(weldepexp=(1)) post //Max: 1
est res iweldepexp
eststo iweldepexp_ethnic_sec: margins, dydx(c.ethnicm) at(weldepexp=(0)) post //Min: 0
est res iweldepexp
eststo iweldepexp_civic_insec: margins, dydx(c.civicm) at(weldepexp=(1)) post //Max: 1
est res iweldepexp
eststo iweldepexp_civic_sec: margins, dydx(c.civicm) at(weldepexp=(0)) post //Min: 0

est res igdppc
eststo igdppc_ethnic_insec: margins, dydx(c.ethnicm) at(gdppc_log=(8.745792)) post //Min: 8.745792 = 6284.1885
est res igdppc
eststo igdppc_ethnic_sec: margins, dydx(c.ethnicm) at(gdppc_log=(11.29394)) post //Max: 11.29394 = 80333.339
est res igdppc
eststo igdppc_civic_insec: margins, dydx(c.civicm) at(gdppc_log=(8.745792)) post //Min: 8.745792 = 6284.1885
est res igdppc
eststo igdppc_civic_sec: margins, dydx(c.civicm) at(gdppc_log=(11.29394)) post //Max: 11.29394 = 80333.339

est res iunemp
eststo iunemp_ethnic_insec: margins, dydx(c.ethnicm) at(unemp=(17.224)) post //Max: 17.224
est res iunemp
eststo iunemp_ethnic_sec: margins, dydx(c.ethnicm) at(unemp=(2.742)) post //Min: 2.742
est res iunemp
eststo iunemp_civic_insec: margins, dydx(c.civicm) at(unemp=(17.224)) post //Max: 17.224
est res iunemp
eststo iunemp_civic_sec: margins, dydx(c.civicm) at(unemp=(2.742)) post //Min: 2.742

est res igini
eststo igini_ethnic_insec: margins, dydx(c.ethnicm) at(gini=(39.6)) post //Max: 39.6
est res igini
eststo igini_ethnic_sec: margins, dydx(c.ethnicm) at(gini=(25.4)) post //Min: 25.4
est res igini
eststo igini_civic_insec: margins, dydx(c.civicm) at(gini=(39.6)) post //Max: 39.6
est res igini
eststo igini_civic_sec: margins, dydx(c.civicm) at(gini=(25.4)) post //Min: 25.4

est res irr
eststo irr_ethnic_insec: margins, dydx(c.ethnicm) at(rr_mean=(30.95)) post //Min: 30.95
est res irr
eststo irr_ethnic_sec: margins, dydx(c.ethnicm) at(rr_mean=(78.88333)) post //Max: 78.88333
est res irr
eststo irr_civic_insec: margins, dydx(c.civicm) at(rr_mean=(30.95)) post //Min: 30.95
est res irr
eststo irr_civic_sec: margins, dydx(c.civicm) at(rr_mean=(78.88333)) post //Max: 78.88333

esttab iincome_ethnic_insec iincome_ethnic_sec iunempexp_ethnic_insec iunempexp_ethnic_sec iweldepexp_ethnic_insec iweldepexp_ethnic_sec igdppc_ethnic_insec igdppc_ethnic_sec iunemp_ethnic_insec iunemp_ethnic_sec igini_ethnic_insec igini_ethnic_sec using "Table 2, Ethnic.rtf", replace b(3) se(2) wide compress staraux alignment(cr) nobase star(+ 0.10 * 0.05 ** 0.01 *** 0.001)

esttab iincome_civic_insec iincome_civic_sec iunempexp_civic_insec iunempexp_civic_sec iweldepexp_civic_insec iweldepexp_civic_sec igdppc_civic_insec igdppc_civic_sec iunemp_civic_insec iunemp_civic_sec igini_civic_insec igini_civic_sec using "Table 2, Civic.rtf", replace b(3) se(2) wide compress staraux alignment(cr) nobase star(+ 0.10 * 0.05 ** 0.01 *** 0.001)

*Table A5: Regression models of the moderating effect of economic hardship on the relation between ethnic or civic national identity and the preference for democracy as opposed to authoritarian alternatives
esttab igdppc iunemp igini iincome iunempexp iweldepexp using "Table A5.rtf", replace b(3) se(2) wide compress sfmt(%10.0f %10.0f %10.3f) scalar(N N_g) ar2 staraux alignment(cr) nobase star(+ 0.10 * 0.05 ** 0.01 *** 0.001)

*Figure A2: Robustness checks for the moderating effect of economic hardship on the relation between ethnic or civic national identity and the preference for democracy as opposed to authoritarian alternatives, Panel Household income
coefplot (iincome, offset(.4) msymbol(O)) (iincome_west, offset(.3) msymbol(D)) (iincome_east, offset(.2) msymbol(S)) (iincome_cvsocdem, offset(0.1) msymbol(T)) (iincome_full, offset(0) msymbol(x)) (iincome_ologit, offset(-.1) msymbol(+)) (iincome_mixed, offset(-.2) msymbol(Oh)) (iincome_civic3, offset(-.3) msymbol(Dh) rename(c.civicm_3item#c.income_cat = c.civicm#c.income_cat)) (iincome_ind3, offset(-.4) msymbol(Th) rename(c.civicm_alt#c.income_cat = c.civicm#c.income_cat)) (iincome_ind2, offset(0) msymbol(Sh)), keep(*ethnicm#* *civicm#* *civicm_3item#* *civicethnicm#* c.civicm_alt#*) xline(0, lpattern(dash) lcolor(gray) lwidth(medthick)) legend(off) ciopts(lcolor(black)) mcolor(black) xlab(, labsize(large)) coeflabels(c.ethnicm#* = "Ethnic NI" c.civicm#* = "Civic NI" c.civicethnicm#* = "Ethnic-civic", labsize(large)) graphregion(color(white)) scheme(s1mono) title("", size(vlarge))
graph export "Figure A2, Household income.png", replace

*Figure A2: Robustness checks for the moderating effect of economic hardship on the relation between ethnic or civic national identity and the preference for democracy as opposed to authoritarian alternatives, Panel Unemployment experience
coefplot (iunempexp, offset(.4) msymbol(O)) (iunempexp_west, offset(.3) msymbol(D)) (iunempexp_east, offset(.2) msymbol(S)) (iunempexp_cvsocdem, offset(0.1) msymbol(T)) (iunempexp_full, offset(0) msymbol(x)) (iunempexp_ologit, offset(-.1) msymbol(+)) (iunempexp_mixed, offset(-.2) msymbol(Oh)) (iunempexp_civic3, offset(-.3) msymbol(Dh) rename(c.civicm_3item#c.unempexp = c.civicm#c.unempexp)) (iunempexp_ind3, offset(-.4) msymbol(Th) rename(c.civicm_alt#c.unempexp = c.civicm#c.unempexp)) (iunempexp_ind2, offset(0) msymbol(Sh)), keep(*ethnicm#* *civicm#* *civicm_3item#* *civicethnicm#* c.civicm_alt#*) xline(0, lpattern(dash) lcolor(gray) lwidth(medthick)) legend(off) ciopts(lcolor(black)) mcolor(black) xlab(, labsize(large)) coeflabels(c.ethnicm#* = "Ethnic NI" c.civicm#* = "Civic NI" c.civicethnicm#* = "Ethnic-civic", labsize(large)) graphregion(color(white)) scheme(s1mono) title("", size(vlarge))
graph export "Figure A2, Unemployment experience.png", replace

*Figure A2: Robustness checks for the moderating effect of economic hardship on the relation between ethnic or civic national identity and the preference for democracy as opposed to authoritarian alternatives, Panel Welfare dependency experience
coefplot (iweldepexp, offset(.4) msymbol(O)) (iweldepexp_west, offset(.3) msymbol(D)) (iweldepexp_east, offset(.2) msymbol(S)) (iweldepexp_cvsocdem, offset(0.1) msymbol(T)) (iweldepexp_full, offset(0) msymbol(x)) (iweldepexp_ologit, offset(-.1) msymbol(+)) (iweldepexp_mixed, offset(-.2) msymbol(Oh)) (iweldepexp_civic3, offset(-.3) msymbol(Dh) rename(c.civicm_3item#c.weldepexp = c.civicm#c.weldepexp)) (iweldepexp_ind3, offset(-.4) msymbol(Th) rename(c.civicm_alt#c.weldepexp = c.civicm#c.weldepexp)) (iweldepexp_ind2, offset(0) msymbol(Sh)), keep(*ethnicm#* *civicm#* *civicm_3item#* *civicethnicm#* c.civicm_alt#*) xline(0, lpattern(dash) lcolor(gray) lwidth(medthick)) legend(off) ciopts(lcolor(black)) mcolor(black) xlab(, labsize(large)) coeflabels(c.ethnicm#* = "Ethnic NI" c.civicm#* = "Civic NI" c.civicethnicm#* = "Ethnic-civic", labsize(large)) graphregion(color(white)) scheme(s1mono) title("", size(vlarge))
graph export "Figure A2, Welfare dependency experience.png", replace

*Figure A2: Robustness checks for the moderating effect of economic hardship on the relation between ethnic or civic national identity and the preference for democracy as opposed to authoritarian alternatives, Panel GDP per capita
coefplot (igdppc, offset(.4) msymbol(O)) (igdppc_west, offset(.3) msymbol(D)) (igdppc_east, offset(.2) msymbol(S)) (igdppc_cvsocdem, offset(0.1) msymbol(T)) (igdppc_full, offset(0) msymbol(x)) (igdppc_ologit, offset(-.1) msymbol(+)) (igdppc_mixed, offset(-.2) msymbol(Oh)) (igdppc_civic3, offset(-.3) msymbol(Dh) rename(c.civicm_3item#c.gdppc_log = c.civicm#c.gdppc_log)) (igdppc_ind3, offset(-.4) msymbol(Th) rename(c.civicm_alt#c.gdppc_log = c.civicm#c.gdppc_log)) (igdppc_ind2, offset(0) msymbol(Sh)), keep(*ethnicm#* *civicm#* *civicm_3item#* *civicethnicm#* c.civicm_alt#*) xline(0, lpattern(dash) lcolor(gray) lwidth(medthick)) legend(off) ciopts(lcolor(black)) mcolor(black) xlab(, labsize(large)) coeflabels(c.ethnicm#* = "Ethnic NI" c.civicm#* = "Civic NI" c.civicethnicm#* = "Ethnic-civic", labsize(large)) graphregion(color(white)) scheme(s1mono) title("", size(vlarge))
graph export "Figure A2, GDP per capita.png", replace

*Figure A2: Robustness checks for the moderating effect of economic hardship on the relation between ethnic or civic national identity and the preference for democracy as opposed to authoritarian alternatives, Panel Unemployment rate
coefplot (iunemp, offset(.4) msymbol(O)) (iunemp_west, offset(.3) msymbol(D)) (iunemp_east, offset(.2) msymbol(S)) (iunemp_cvsocdem, offset(0.1) msymbol(T)) (iunemp_full, offset(0) msymbol(x)) (iunemp_ologit, offset(-.1) msymbol(+)) (iunemp_mixed, offset(-.2) msymbol(Oh)) (iunemp_civic3, offset(-.3) msymbol(Dh) rename(c.civicm_3item#c.unemp = c.civicm#c.unemp)) (iunemp_ind3, offset(-.4) msymbol(Th) rename(c.civicm_alt#c.unemp = c.civicm#c.unemp)) (iunemp_ind2, offset(0) msymbol(Sh)), keep(*ethnicm#* *civicm#* *civicm_3item#* *civicethnicm#* c.civicm_alt#*) xline(0, lpattern(dash) lcolor(gray) lwidth(medthick)) legend(off) ciopts(lcolor(black)) mcolor(black) xlab(, labsize(large)) coeflabels(c.ethnicm#* = "Ethnic NI" c.civicm#* = "Civic NI" c.civicethnicm#* = "Ethnic-civic", labsize(large)) graphregion(color(white)) scheme(s1mono) title("", size(vlarge))
graph export "Figure A2, Unemployment rate.png", replace

*Figure A2: Robustness checks for the moderating effect of economic hardship on the relation between ethnic or civic national identity and the preference for democracy as opposed to authoritarian alternatives, Panel Gini index
coefplot (igini, offset(.4) msymbol(O)) (igini_west, offset(.3) msymbol(D)) (igini_east, offset(.2) msymbol(S)) (igini_cvsocdem, offset(0.1) msymbol(T)) (igini_full, offset(0) msymbol(x)) (igini_ologit, offset(-.1) msymbol(+)) (igini_mixed, offset(-.2) msymbol(Oh)) (igini_civic3, offset(-.3) msymbol(Dh) rename(c.civicm_3item#c.gini = c.civicm#c.gini)) (igini_ind3, offset(-.4) msymbol(Th) rename(c.civicm_alt#c.gini = c.civicm#c.gini)) (igini_ind2, offset(0) msymbol(Sh)), keep(*ethnicm#* *civicm#* *civicm_3item#* *civicethnicm#* c.civicm_alt#*) xline(0, lpattern(dash) lcolor(gray) lwidth(medthick)) legend(off) ciopts(lcolor(black)) mcolor(black) xlab(, labsize(large)) coeflabels(c.ethnicm#* = "Ethnic NI" c.civicm#* = "Civic NI" c.civicethnicm#* = "Ethnic-civic", labsize(large)) graphregion(color(white)) scheme(s1mono) title("", size(vlarge))
graph export "Figure A2, Gini index.png", replace

*Figure A2: Robustness checks for the moderating effect of economic hardship on the relation between ethnic or civic national identity and the preference for democracy as opposed to authoritarian alternatives, Panel Replacement rate
coefplot (irr, offset(.4) msymbol(O)) (irr_west, offset(.3) msymbol(D)) (irr_east, offset(.2) msymbol(S)) (irr_cvsocdem, offset(0.1) msymbol(T)) (irr_full, offset(0) msymbol(x)) (irr_ologit, offset(-.1) msymbol(+)) (irr_mixed, offset(-.2) msymbol(Oh)) (irr_civic3, offset(-.3) msymbol(Dh) rename(c.civicm_3item#c.rr_mean = c.civicm#c.rr_mean)) (irr_ind3, offset(-.4) msymbol(Th) rename(c.civicm_alt#c.rr_mean = c.civicm#c.rr_mean)) (irr_ind2, offset(0) msymbol(Sh)), keep(*ethnicm#* *civicm#* *civicm_3item#* *civicethnicm#* c.civicm_alt#*) xline(0, lpattern(dash) lcolor(gray) lwidth(medthick)) legend(off) ciopts(lcolor(black)) mcolor(black) xlab(, labsize(large)) coeflabels(c.ethnicm#* = "Ethnic NI" c.civicm#* = "Civic NI" c.civicethnicm#* = "Ethnic-civic", labsize(large)) graphregion(color(white)) scheme(s1mono) title("", size(vlarge))
graph export "Figure A2, Replacement rate.png", replace

*Figure A2: Robustness checks for the moderating effect of economic hardship on the relation between ethnic or civic national identity and the preference for democracy as opposed to authoritarian alternatives, Panel Legend
coefplot (igdppc, offset(.4) msymbol(O)) (igdppc_west, offset(.3) msymbol(D)) (igdppc_east, offset(.2) msymbol(S)) (igdppc_cvsocdem, offset(0.1) msymbol(T)) (igdppc_full, offset(0) msymbol(x)) (igdppc_ologit, offset(-.1) msymbol(+)) (igdppc_mixed, offset(-.2) msymbol(Oh)) (igdppc_civic3, offset(-.3) msymbol(Dh) rename(c.civicm_3item#c.gdppc_log = c.civicm#c.gdppc_log)) (igdppc_ind3, offset(-.4) msymbol(Th) rename(c.civicm_alt#c.gdppc_log = c.civicm#c.gdppc_log)) (igdppc_ind2, offset(0) msymbol(Sh)), keep(*ethnicm#* *civicm#* *civicm_3item#* *civicethnicm#* c.civicm_alt#*) xline(0, lpattern(dash) lcolor(gray) lwidth(medthick)) legend(order(2 "Main model" 4 "Western Europe" 6 "Eastern Europe" 8 "Less controls" 10 "More controls" 12 "Ordered logit" 14 "Multilevel" 16 "3-item civic" 18 "Civic NI alternative" 20 "Ethnic-civic") rows(4)) ciopts(lcolor(black)) mcolor(black) xlab(, labsize(large)) coeflabels(c.ethnicm#* = "Ethnic NI" c.civicm#* = "Civic NI" c.civicethnicm#* = "Ethnic-civic", labsize(large)) graphregion(color(white)) scheme(s1mono) title("", size(vlarge))
graph export "Figure A2, Legend.png", replace







*******************************************************************************

*** 5. Replication with EVS 2008

use "EPSR Erhardt et al 2008 replication", clear
xtset country
global controls "c.age##c.age sex education income_cat i.workstat unempexp weldepexp i.maritalstat children religious_attendance i.migration_background c.rile##c.rile interestpolitics gentrust specificsupport"


** Replication direct effects

*Models
xtreg dap_democracy civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls , vce(rob) fe
eststo democracy

xtreg dap_leader civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls , vce(rob) fe
eststo leader

xtreg dap_army civicethnic_ancestry civicethnic_born civicethnic_culture civicethnic_language civicethnic_institutions $controls , vce(rob) fe
eststo army

*Figure A1: Robustness checks for the relation between ethnic or civic national identity and support for democracy as opposed to authoritarian alternatives, Panel EVS 2008 replication
coefplot democracy, bylabel(Democratic rule) || leader, bylabel(Leader rule) || army, bylabel(Army rule) ||, keep(civicethnic_*) xline(0, lpattern(dash) lcolor(gray) lwidth(medthick)) ciopts(lcolor(black)) mcolor(black) xlab(, labsize(large)) coeflabels(civicethnic_ancestry = "Ancestry" civicethnic_born = "Born" civicethnic_culture = "Culture" civicethnic_language = "Language" civicethnic_institutions = "Institutions", labsize(large)) graphregion(color(white)) scheme(s1mono) byopts(rows(1)) 
graph export "Figure A1, EVS 2008 replication.png", replace



** Replication interaction effects

*Models
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.income_cat) $controls , vce(rob) fe
eststo iincome
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.unempexp) $controls , vce(rob) fe
eststo iunempexp
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.weldepexp) $controls , vce(rob) fe
eststo iweldepexp

xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.gdppc_log) $controls , vce(rob) fe
eststo igdppc
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.unemp) $controls , vce(rob) fe
eststo iunemp
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.gini) $controls , vce(rob) fe
eststo igini
xtreg prefsystemm3 c.ethnicm c.civicm (c.ethnicm c.civicm)#(c.rr_mean) $controls , vce(rob) fe
eststo irr

*Table A6: Robustness checks for the moderating effect of economic hardship on the relation between ethnic or civic national identity and the preference for democracy as opposed to authoritarian alternatives, EVS 2008 replication
esttab igdppc iunemp igini iincome iunempexp iweldepexp using "Table A6.rtf", replace b(3) se(2) wide compress sfmt(%10.0f %10.0f %10.3f) scalar(N N_g) ar2 staraux alignment(cr) nobase star(+ 0.10 * 0.05 ** 0.01 *** 0.001)

