*******************************************************************************
*****                     Replication code for                             ****
***** Erhardt et al. - National Identity between Democracy and Autocracy   ****
*****                 Part I: Creating the data set                        ****
*******************************************************************************
    
*Note: All data sets were downloaded from the sources given in the article





*******************************************************************************

*** 1. Loading the EVS data set

use "ZA7500_v2-0-0.dta", clear

*Create country identifier
*net install dm0038_1 // kountry needs to be installed
kountry country, from(iso3n)
replace NAMES_STD = "Serbia" if NAMES_STD == "688"

save "EPSR Erhardt et al.dta", replace



*******************************************************************************

*** 2. Merge country data

*WorldBank GDP per capita, Data from year 2017
import excel "WorldBank GDP per capita.xlsx", firstrow clear
kountry cname, from(other)
replace NAMES_STD = "Serbia" if NAMES_STD=="Yugoslavia"
drop cname
tempfile gdppc
save `gdppc'

use "EPSR Erhardt et al", clear
merge m:m NAMES_STD using `gdppc', keep(match master) nogen
gen gdppc_log = log(gdppc)
label var gdppc "GDP per capita"
label var gdppc_log "GDP per capita (logged)"
save "EPSR Erhardt et al", replace

*WorldBank Unemployment rate, Data from year 2017
import excel "WorldBank Unemployment.xlsx", firstrow clear
kountry cname, from(other)
replace NAMES_STD = "Serbia" if NAMES_STD=="Yugoslavia"
drop cname
tempfile unemp
save `unemp'

use "EPSR Erhardt et al", clear
merge m:m NAMES_STD using `unemp', keep(match master) nogen
label var unemp "Unemployment rate"
save "EPSR Erhardt et al.dta", replace

*WorldBank Gini, Data from year 2017 or earlier years if missing
import excel "WorldBank Gini.xlsx", firstrow clear
kountry cname, from(other)
replace NAMES_STD = "Serbia" if NAMES_STD=="Yugoslavia"
drop cname
gen gini=.
foreach var of varlist y2017 y2016 y2015 y2014 y2013 y2012 y2011 y2010 y2009 {
replace gini = `var' if gini==.
}
drop y*
tempfile gini
save `gini'

use "EPSR Erhardt et al", clear
merge m:m NAMES_STD using `gini', keep(match master) nogen
label var gini "Gini index"
save "EPSR Erhardt et al", replace

*CWED Replacement rate data, Data from year 2010 (later years not available)
import excel "CWED.xlsx", firstrow clear
gen rr_unemp = (US100+UC1000)/2
gen rr_sickness = (SS100+SC1000)/2
gen rr_pension = (MPS100+MPC1000)/2
kountry COUNTRY, from(other)
keep if YEAR==2010
egen rr_mean = rowmean(rr_*)
replace rr_mean = . if rr_unemp==.|rr_sickness==.|rr_pension==.
keep NAMES_STD rr_mean
replace rr_mean = rr_mean*100
tempfile cwed
save `cwed'

use "EPSR Erhardt et al", clear
merge m:m NAMES_STD using `cwed', keep(match master) nogen
label var rr_mean "Replacement rate (mean unemployment, sickness, pension)"
save "EPSR Erhardt et al", replace

*World Bank GDP Growth (robustness check), Data from year 2017
import excel "WorldBank GDP growth.xlsx", firstrow clear
kountry cname, from(other)
replace NAMES_STD = "Serbia" if NAMES_STD=="Yugoslavia"
drop cname
tempfile growth
save `growth'

use "EPSR Erhardt et al", clear
merge m:m NAMES_STD using `growth', keep(match master) nogen
label var growth "GDP Growth"
save "EPSR Erhardt et al", replace

*KOF-Index, Data from year 2016 (later years not available)
use "KOF Index.dta", clear
keep if year==2016
kountry country, from(other)
keep NAMES_STD KOFGI
replace NAMES_STD = "Serbia" if NAMES_STD == "Yugoslavia"
tempfile kof
save `kof'

use "EPSR Erhardt et al", clear
merge m:m NAMES_STD using `kof', keep(match master) nogen
save "EPSR Erhardt et al", replace

*World Bank Net Migration Rate, Data from year 2017
import excel "WorldBank Net Migration.xlsx", firstrow clear
tempfile netmigration
save `netmigration'
import excel "WorldBank Population.xlsx", firstrow clear
merge m:m cname using `netmigration', keep(match master) nogen
kountry cname, from(other)
replace NAMES_STD = "Serbia" if NAMES_STD=="Yugoslavia"
drop cname
gen netmigrationrate = netmigration*1000/population
drop population netmigration
tempfile netmigration
save `netmigration'

use "EPSR Erhardt et al", clear
merge m:m NAMES_STD using `netmigration', keep(match master) nogen
label var netmigrationrate "Net migration rate"
save "EPSR Erhardt et al", replace

*WGI Government Effectiveness, Data from year 2017
use "wgidataset-fixed.dta", clear
keep if year==2017
kountry countryname, from(other)
replace NAMES_STD = "Serbia" if NAMES_STD=="Yugoslavia"
keep NAMES_STD gee
tempfile wgi
save `wgi'

use "EPSR Erhardt et al", clear
merge m:m NAMES_STD using `wgi', keep(match master) nogen
save "EPSR Erhardt et al", replace

*Freedom House, Data from year 2017
import excel "Freedom House.xlsx", firstrow clear
kountry cname, from(other)
drop if cname == "Yugoslavia"
drop if cname == "USSR"
replace NAMES_STD = "Serbia" if NAMES_STD=="Yugoslavia"
drop cname
tempfile fh
save `fh'

use "EPSR Erhardt et al", clear
merge m:m NAMES_STD using `fh', keep(match master) nogen
label var fh "Freedom House Index"
save "EPSR Erhardt et al", replace






*******************************************************************************

*** 3. Code key variables

**Dependent variables: Democracy-autocracy preference

*Individual items
clonevar dap_democracy = v148
clonevar dap_leader = v145
clonevar dap_army = v147

foreach var of varlist dap_* {
replace `var' = . if `var'<0
recode `var' (4=1) (3=2) (2=3) (1=4)
label define `var' 1 "very bad" 2 "fairly bad" 3 "fairly good" 4 "very good", replace
label val `var' `var'
}
label var dap_democracy "Support for democracy"
label var dap_leader "Support for strong leader"
label var dap_army "Support for army rule"

*Democracy-autocracy preference index
gen prefsystemm3 = (dap_democracy/3) + ((5-dap_leader)/3) + ((5-dap_army)/3)
label var prefsystemm3 "Democracy-autocracy preference index"






**Independent variables: National identity

*Individual items
clonevar civicethnic_ancestry = v191
clonevar civicethnic_born = v189
clonevar civicethnic_culture = v193
clonevar civicethnic_language = v192
clonevar civicethnic_institutions = v190

foreach var of varlist civicethnic_* {
replace `var' = . if `var'<0
recode `var' (4=1) (3=2) (2=3) (1=4)
label define `var' 1 "Not at all important" 2 "Not important" 3 "Quite important" 4 "Very important", replace
label val `var' `var'
}
label var civicethnic_ancestry "National identity: ancestry"
label var civicethnic_born "National identity: born"
label var civicethnic_culture "National identity: culture"
label var civicethnic_language "National identity: language"
label var civicethnic_institutions "National identity: institutions"

*Ethnic national identity index
egen ethnicm = rowmean(civicethnic_born civicethnic_ancestry)
replace ethnicm = . if civicethnic_born==.|civicethnic_ancestry==.
label var ethnicm "Ethnic national identity index"

*Civic national identity index: 2-item (used in main text), 3-item (used in OA), alternative (used in OA)
egen civicm = rowmean(civicethnic_institutions civicethnic_language)
replace civicm = . if civicethnic_institutions==.|civicethnic_language==.
label var civicm "Civic national identity index"

egen civicm_3item = rowmean(civicethnic_institutions civicethnic_language civicethnic_culture)
replace civicm_3item = . if civicethnic_institutions==.|civicethnic_language==.|civicethnic_culture==.
label var civicm_3item "Civic national identity index (3-item)"

gen civicm_alt = civicm*((4-ethnicm)/3)
label var civicm_alt "Civic national identity index (alternative)"

*Combined Civic-ethnic national identity index (used in OA)
gen civicethnicm = civicethnic_ancestry/5 + civicethnic_born/5 + (5-civicethnic_culture)/5 + (5-civicethnic_language)/5 + (5-civicethnic_institutions)/5
label var civicethnicm "Civic-ethnic combined national identity index (low values = civic)"





**Moderator variables:

*Income decile
clonevar income_cat = v261
replace income_cat = . if income_cat <0
label var income_cat "Household income"

*Unemployment experience
clonevar unempexp = v259
replace unempexp = . if unempexp <0
replace unempexp = 0 if unempexp==2
label define unempexp 0 "no" 1 "yes"
label val unempexp unempexp
label var unempexp "Unemployment experience"

*Welfare dependency experience
clonevar weldepexp = v260
replace weldepexp = . if weldepexp <0
replace weldepexp = 0 if weldepexp==2
label define weldepexp 0 "no" 1 "yes"
label val weldepexp weldepexp
label var weldepexp "Welfare dependency experience"

*Reorder other moderator and country control variables
order gdppc-fh, after(weldepexp)





**Control variables

*Age
replace age = . if age<0
gen age2 = age*age
order age, after(gini)
label var age "Age"
label var age2 "Age (squared)"

*Sex
clonevar sex = v225
replace sex = . if sex <0
recode sex (2=0)
label define sex 0 "female" 1 "male", replace
label val sex sex
label var sex "Sex"

*Education
clonevar education = v243_ISCED_1
replace education = . if education <0 | education==66
label var education "Education"

*Work status
clonevar workstat = v244
replace workstat = . if workstat <0
recode workstat (8=4) (7=6) (10 4 6 9 = 7)
label define workstat 1 "full-time employed" 2 "part-time employed" 3 "self-employed" 4 "unemployed" 5 "retired" 6 "student" 7 "other", replace
label val workstat workstat
tab workstat, gen(workstat)
label var workstat "Work status"

*Marital status
clonevar maritalstat = v234
replace maritalstat = . if maritalstat <0
recode maritalstat (1=2) (6=1) (5=4)
label define maritalstat 1 "single" 2 "married/registered partnership" 3 "widowed" 4 "divorced/separated" 5 "Very good"
label val maritalstat maritalstat
tab maritalstat, gen(maritalstat)
label var maritalstat "Marital status"

*Children
clonevar children = v239_r
replace children = . if children<0
replace children = 1 if children > 1 & children!=.
label define children 0 "no" 1 "yes"
label val children children
label var children "Children"

*Religious attendance
clonevar religious_attendance = v54
replace religious_attendance = . if religious_attendance<0
replace religious_attendance = 8-religious_attendance
label define religious_attendance 1 "never, practically never" 2 "less often" 3 "once a year" 4 "only on specific holy days" 5 " once a month" 6 "once a week" 7 "more than once a week", replace
label val religious_attendance religious_attendance
label var religious_attendance "Religious attendance"

*Migration background
clonevar born = v227
clonevar born_father = v230
clonevar born_mother = v232

foreach var of varlist born* {
replace `var' = . if `var'<0
recode `var' (2=0)
label define `var' 1 "yes" 0 "no", replace
label val `var' `var'
}

gen migration_background = .
replace migration_background = 1 if born==1&born_father==1&born_mother==1
replace migration_background = 2 if born==1&(born_father==0|born_mother==0)
replace migration_background = 3 if born==0
label define migration_background 1 "none" 2 "second generation" 3 "first generation", replace
label val migration_background migration_background
tab migration_background, gen(migration_background)
label var migration_background "Migration background"
drop born*

*Left-right self-placement
clonevar rile=v102
replace rile = . if rile<0
gen rile2 = rile*rile
label var rile "Left-right self-placement"
label var rile2 "Left-right self-placement (squared)"

*Interest in politics
clonevar interestpolitics = v97
replace interestpolitics = . if interestpolitics <0
recode interestpolitics (4=1) (3=2) (2=3) (1=4)
label define interestpolitics 1 "not at all interested" 2 "not very interested" 3 "somewhat interested" 4 "very interested"
label val interestpolitics interestpolitics
label var interestpolitics "Interest in politics"

*Generalized trust
clonevar gentrust = v31
replace gentrust = . if gentrust <0
recode gentrust (2=0)
label define gentrust 0 "can't be too careful" 1 "most people can be trusted", replace
label val gentrust gentrust
label var gentrust "Generalized trust"

*Specific support for democracy
clonevar specificsupport = v144
replace specificsupport = . if specificsupport<0
label var specificsupport "Specific support for democracy"

*Regarding political system as democratic
clonevar polsystem_democratic = v143
replace polsystem_democratic = . if polsystem_democratic<0
label var polsystem_democratic "Regarding political system as democratic"

*Attitudes towards immigrants
clonevar immigrants = v184
replace immigrants = . if immigrants <0
recode immigrants (1=5) (2=4) (4=2) (5=1)
label define immigrants 1 "Very bad" 2 "Quite bad" 3 "Neither good, nor bad" 4 "Quite good" 5 "Very good"
label val immigrants immigrants
label var immigrants "Attitudes towards immigrants"

*Particularized trust
clonevar trust_particularized = v34
replace trust_particularized = . if trust_particularized<0
recode trust_particularized (4=1) (3=2) (2=3) (1=4)
label define trust_particularized 1 "Do not trust at all" 2 "Do not trust very much" 3 "Trust somewhat" 4 "Trust completely", replace
label val trust_particularized trust_particularized
label var trust_particularized "Particularized trust"

*Club membership
gen clubmem = 0 if v9>=1|v10>=1|v11>=1|v12>=1|v13>=1|v14>=1|v15>=1|v16>=1|v17>=1|v18>=1|v19>=1
foreach var of varlist v9-v19 {
replace clubmem = 1 if `var' == 1
}
label define clubmem 0 "no" 1 "yes"
label val clubmem clubmem
label var clubmem "Club membership"

*National pride
clonevar nationalpride = v170
replace nationalpride = . if nationalpride <0
recode nationalpride (4=1) (3=2) (2=3) (1=4)
label define nationalpride 1 "not at all proud" 2 "not very proud" 3 "quite proud" 4 "very proud"
label val nationalpride nationalpride
label var nationalpride "National pride"

*Liberal vs. traditional/conservative values
clonevar values_homosexuality = v153
clonevar values_abortion = v154
clonevar values_divorce = v155
clonevar values_euthanasia = v156
foreach var of varlist values_* {
replace `var' = . if `var'<0
}
factor values_homosexuality-values_euthanasia, pcf
generate valuesm = (values_homosexuality + values_abortion + values_divorce + values_euthanasia)/4
drop values_*
label var valuesm "Liberal vs. traditional values"

*Authoritarian attitudes
clonevar authoritarianism = v114
replace authoritarianism = . if authoritarianism<0
recode authoritarianism (1=3) (2=1) (3=2)
label define authoritarianism 1 "Bad" 2 "Don't mind" 3 "Good"
label val authoritarianism authoritarianism
label var authoritarianism "Authoritarian attitudes"



**Other variables
*West-East
recode country (8 31 51 100 112 191 203 233 268 348 440 616 642 643 688 703 705 = 0) (40 208 246 250 276 352 380 528 578 724 752 756 826 = 1), gen(west)
label define west 0 "Eastern Europe" 1 "Western Europe"
label val west west
label var west "Western vs. Eastern Europe"






*******************************************************************************

*** 4. Drop unneeded cases and variables

*Drop nondemocratic countries (Freedom House > 2.5, Polity IV < 6 --> Albania, Azerbaijan, Armenia, Belarus, Georgia, Russia), see footnote 7
drop if country==8|country==31|country==51|country==112|country==268|country==643

*Drop variables not needed
keep studyno-version id_cocas year country NAMES_STD dap_democracy-west


save "EPSR Erhardt et al.dta", replace


















*******************************************************************************

*** 5. Same procedure for the EVS 2008 replication

** Loading the data

use "ZA4800_v4-0-0.dta", clear

*Create country identifier
*net install dm0038_1 // kountry needs to be installed
kountry country, from(iso3n)
replace NAMES_STD = "Serbia" if NAMES_STD == "688"

save "EPSR Erhardt et al 2008 replication.dta", replace


** Merge country data

*WorldBank GDP per capita, Data from year 2008
import excel "WorldBank GDP per capita.xlsx", firstrow clear
kountry cname, from(other)
replace NAMES_STD = "Serbia" if NAMES_STD=="Yugoslavia"
drop cname
tempfile gdppc
save `gdppc'

use "EPSR Erhardt et al 2008 replication.dta", clear
merge m:m NAMES_STD using `gdppc', keep(match master) nogen
gen gdppc_log = log(gdppc)
label var gdppc "GDP per capita"
label var gdppc_log "GDP per capita (logged)"
save "EPSR Erhardt et al 2008 replication.dta", replace

*WorldBank Unemployment rate, Data from year 2008
import excel "WorldBank Unemployment.xlsx", firstrow clear
kountry cname, from(other)
replace NAMES_STD = "Serbia" if NAMES_STD=="Yugoslavia"
drop cname
tempfile unemp
save `unemp'

use "EPSR Erhardt et al 2008 replication.dta", clear
merge m:m NAMES_STD using `unemp', keep(match master) nogen
label var unemp "Unemployment rate"
save "EPSR Erhardt et al 2008 replication.dta", replace

*WorldBank Gini, Data from year 2017 or earlier years if missing
import excel "WorldBank Gini.xlsx", firstrow clear
kountry cname, from(other)
replace NAMES_STD = "Serbia" if NAMES_STD=="Yugoslavia"
drop cname
gen gini=.
foreach var of varlist y2008 y2007 y2006 y2005 y2004 y2003 y2002 y2001 y2000 y1999 {
replace gini = `var' if gini==.
}
drop y*
tempfile gini
save `gini'

use "EPSR Erhardt et al 2008 replication.dta", clear
merge m:m NAMES_STD using `gini', keep(match master) nogen
label var gini "Gini index"
save "EPSR Erhardt et al 2008 replication.dta", replace

*CWED Replacement rate data, Data from year 2010 (later years not available)
import excel "CWED.xlsx", firstrow clear
gen rr_unemp = (US100+UC1000)/2
gen rr_sickness = (SS100+SC1000)/2
gen rr_pension = (MPS100+MPC1000)/2
kountry COUNTRY, from(other)
keep if YEAR==2008
egen rr_mean = rowmean(rr_*)
replace rr_mean = . if rr_unemp==.|rr_sickness==.|rr_pension==.
keep NAMES_STD rr_mean
replace rr_mean = rr_mean*100
tempfile cwed
save `cwed'

use "EPSR Erhardt et al 2008 replication.dta", clear
merge m:m NAMES_STD using `cwed', keep(match master) nogen
label var rr_mean "Replacement rate (mean unemployment, sickness, pension)"
save "EPSR Erhardt et al 2008 replication.dta", replace



**Dependent variables: Democracy-autocracy preference

*Individual items
clonevar dap_democracy = v228
clonevar dap_leader = v225
clonevar dap_army = v227

foreach var of varlist dap_* {
replace `var' = . if `var'<0
recode `var' (4=1) (3=2) (2=3) (1=4)
label define `var' 1 "very bad" 2 "fairly bad" 3 "fairly good" 4 "very good", replace
label val `var' `var'
}
label var dap_democracy "Support for democracy"
label var dap_leader "Support for strong leader"
label var dap_army "Support for army rule"

*Democracy-autocracy preference index
gen prefsystemm3 = (dap_democracy/3) + ((5-dap_leader)/3) + ((5-dap_army)/3)
label var prefsystemm3 "Democracy-autocracy preference index"






**Independent variables: National identity

*Individual items
clonevar civicethnic_ancestry = v278
clonevar civicethnic_born = v276
clonevar civicethnic_culture = v280
clonevar civicethnic_language = v279
clonevar civicethnic_institutions = v277

foreach var of varlist civicethnic_* {
replace `var' = . if `var'<0
recode `var' (4=1) (3=2) (2=3) (1=4)
label define `var' 1 "Not at all important" 2 "Not important" 3 "Quite important" 4 "Very important", replace
label val `var' `var'
}
label var civicethnic_ancestry "National identity: ancestry"
label var civicethnic_born "National identity: born"
label var civicethnic_culture "National identity: culture"
label var civicethnic_language "National identity: language"
label var civicethnic_institutions "National identity: institutions"

*Ethnic national identity index
egen ethnicm = rowmean(civicethnic_born civicethnic_ancestry)
replace ethnicm = . if civicethnic_born==.|civicethnic_ancestry==.
label var ethnicm "Ethnic national identity index"

*Civic national identity index: 2-item (used in main text), 3-item (used in OA), alternative (used in OA)
egen civicm = rowmean(civicethnic_institutions civicethnic_language)
replace civicm = . if civicethnic_institutions==.|civicethnic_language==.
label var civicm "Civic national identity index"

egen civicm_3item = rowmean(civicethnic_institutions civicethnic_language civicethnic_culture)
replace civicm_3item = . if civicethnic_institutions==.|civicethnic_language==.|civicethnic_culture==.
label var civicm_3item "Civic national identity index (3-item)"

gen civicm_alt = civicm*((4-ethnicm)/3)
label var civicm_alt "Civic national identity index (alternative)"

*Combined Civic-ethnic national identity index (used in OA)
gen civicethnicm = civicethnic_ancestry/5 + civicethnic_born/5 + (5-civicethnic_culture)/5 + (5-civicethnic_language)/5 + (5-civicethnic_institutions)/5
label var civicethnicm "Civic-ethnic combined national identity index (low values = civic)"





**Moderator variables:

*Income decile
clonevar income_cat = v353M_ppp
replace income_cat = . if income_cat <0
label var income_cat "Household income"

*Unemployment experience
clonevar unempexp = v349
replace unempexp = . if unempexp <0
replace unempexp = 0 if unempexp==2
label define unempexp 0 "no" 1 "yes"
label val unempexp unempexp
label var unempexp "Unemployment experience"

*Welfare dependency experience
clonevar weldepexp = v351
replace weldepexp = . if weldepexp <0
replace weldepexp = 0 if weldepexp==2
label define weldepexp 0 "no" 1 "yes"
label val weldepexp weldepexp
label var weldepexp "Welfare dependency experience"

*Reorder other moderator and country control variables
order gdppc-rr_mean, after(weldepexp)





**Control variables

*Age
replace age = . if age<0
gen age2 = age*age
order age, before(age2)
label var age "Age"
label var age2 "Age (squared)"

*Sex
clonevar sex = v302
replace sex = . if sex <0
recode sex (2=0)
label define sex 0 "female" 1 "male", replace
label val sex sex
label var sex "Sex"

*Education
clonevar education = v336
replace education = . if education <0 | education==66
label var education "Education"

*Work status
clonevar workstat = v337
replace workstat = . if workstat <0
recode workstat (8=4) (7=6) (10 4 6 9 = 7)
label define workstat 1 "full-time employed" 2 "part-time employed" 3 "self-employed" 4 "unemployed" 5 "retired" 6 "student" 7 "other", replace
label val workstat workstat
tab workstat, gen(workstat)
label var workstat "Work status"

*Marital status
clonevar maritalstat = v313
replace maritalstat = . if maritalstat <0
recode maritalstat (1=2) (6=1) (5=4)
label define maritalstat 1 "single" 2 "married/registered partnership" 3 "widowed" 4 "divorced/separated" 5 "Very good"
label val maritalstat maritalstat
tab maritalstat, gen(maritalstat)
label var maritalstat "Marital status"

*Children
clonevar children = v321
replace children = . if children<0
replace children = 1 if children > 1 & children!=.
label define children 0 "no" 1 "yes"
label val children children
label var children "Children"

*Religious attendance
clonevar religious_attendance = v109
replace religious_attendance = . if religious_attendance<0
replace religious_attendance = 8-religious_attendance
label define religious_attendance 1 "never, practically never" 2 "less often" 3 "once a year" 4 "only on specific holy days" 5 " once a month" 6 "once a week" 7 "more than once a week", replace
label val religious_attendance religious_attendance
label var religious_attendance "Religious attendance"

*Migration background
clonevar born = v306
clonevar born_father = v309
clonevar born_mother = v311

foreach var of varlist born* {
replace `var' = . if `var'<0
recode `var' (2=0)
label define `var' 1 "yes" 0 "no", replace
label val `var' `var'
}

gen migration_background = .
replace migration_background = 1 if born==1&born_father==1&born_mother==1
replace migration_background = 2 if born==1&(born_father==0|born_mother==0)
replace migration_background = 3 if born==0
label define migration_background 1 "none" 2 "second generation" 3 "first generation", replace
label val migration_background migration_background
tab migration_background, gen(migration_background)
label var migration_background "Migration background"
drop born*

*Left-right self-placement
clonevar rile=v193
replace rile = . if rile<0
gen rile2 = rile*rile
label var rile "Left-right self-placement"
label var rile2 "Left-right self-placement (squared)"

*Interest in politics
clonevar interestpolitics = v186
replace interestpolitics = . if interestpolitics <0
recode interestpolitics (4=1) (3=2) (2=3) (1=4)
label define interestpolitics 1 "not at all interested" 2 "not very interested" 3 "somewhat interested" 4 "very interested"
label val interestpolitics interestpolitics
label var interestpolitics "Interest in politics"

*Generalized trust
clonevar gentrust = v62
replace gentrust = . if gentrust <0
recode gentrust (2=0)
label define gentrust 0 "can't be too careful" 1 "most people can be trusted", replace
label val gentrust gentrust
label var gentrust "Generalized trust"

*Specific support for democracy
clonevar specificsupport = v223
replace specificsupport = . if specificsupport<0
label var specificsupport "Specific support for democracy"



**Other variables
*West-East
recode country (8 31 51 100 112 191 203 233 268 348 440 616 642 643 688 703 705 = 0) (40 208 246 250 276 352 380 528 578 724 752 756 826 = 1) (else=.), gen(west)
label define west 0 "Eastern Europe" 1 "Western Europe"
label val west west
label var west "Western vs. Eastern Europe"




** Drop unneeded cases and variables

*Drop nondemocratic countries (Freedom House > 2.5, Polity IV < 6 --> Albania, Azerbaijan, Armenia, Belarus, Georgia, Russia) and countries not in EVS 2017, see footnote 7
drop if country==8|country==31|country==51|country==112|country==268|country==643|west==.

*Drop variables not needed
keep studyno-version id_cocas year country NAMES_STD dap_democracy-west


save "EPSR Erhardt et al 2008 replication.dta", replace